@@ -492,18 +492,18 @@
 #'
 #' @examples
 #'
-#' \donttest{
+#' \dontrun{
 #' # Data from the advanced ovarian cancer randomized clinical trials.
 #' data(dataOvarian)
 #' joint.surro.Gumbel <- jointSurroCopPenal(data = dataOvarian, int.method = 0,
 #'       n.knots = 8, maxit = 50, kappa.use = 4, nb.mc = 1000, typecopula = 2,
-#'       print.iter = F, scale = 1/365)
+#'       print.iter = FALSE, scale = 1/365)
 #'
 #' print(joint.surro.Gumbel)
 #'
 #' joint.surro.Clayton <- jointSurroCopPenal(data = dataOvarian, int.method = 0,
 #'       n.knots = 8, maxit = 50, kappa.use = 4, nb.mc = 1000, typecopula = 1,
-#'       print.iter = F, scale = 1/365)
+#'       print.iter = FALSE, scale = 1/365)
 #'
 #' print(joint.surro.Clayton)
 #' }
@@ -750,7 +750,7 @@ jointSurroCopPenal = function(data, maxit = 40, indicator.alpha = 1, frail.base
       #kappa0 <- frailtypack:::kappa_val_croisee(don_S=donnees,don_T=death,njeu=1,n_obs=nsujet1,n_node=n.knots,adjust_S=1,adjust_T=1,kapp_0 = 0)
       kappa0 <- kappa_val_croisee(don_S=donnees,don_T=death,njeu=1,n_obs=nsujet1,n_node=n.knots,adjust_S=1,adjust_T=1,kapp_0 = 0, print.times = F, scale = scale)
       # I deleate the created text file
-      file.remove(dir(pattern="kappa_valid_crois.txt"))
+      #file.remove(dir(pattern="kappa_valid_crois.txt"))
     }
     # else, we use the kappa give by the user
   }else{
